MacroRegion

Struct MacroRegion 

pub struct MacroRegion { /* private fields */ }
Byte range of a macro call that contributed to this parse.

Returned by super::AnyParsedStatement::macro_regions.

Implementations

Source

impl MacroRegion

pub fn call_offset(&self) -> u32

Byte offset of the macro call in the original source.

pub fn call_length(&self) -> u32

Byte length of the entire macro call.