pub struct Token<'a>(/* private fields */);Expand description
Token emitted by Tokenizer, including kind and source slice.
Typical usage:
- Inspect token kind via
token_type. - Read exact source text via
text.
pub struct Token<'a>(/* private fields */);Token emitted by Tokenizer, including kind and source slice.
Typical usage:
token_type.text.