pub struct MacroRegion { /* private fields */ }Expand description
Byte range of a macro call that contributed to this parse.
Returned by super::AnyParsedStatement::macro_regions.
Implementations
Sourceimpl MacroRegion
impl MacroRegion
Sourcepub fn call_offset(&self) -> u32
pub fn call_offset(&self) -> u32
Byte offset of the macro call in the original source.
Sourcepub fn call_length(&self) -> u32
pub fn call_length(&self) -> u32
Byte length of the entire macro call.