#[non_exhaustive]pub enum SqliteVersion {
Show 41 variants
V3_12,
V3_13,
V3_14,
V3_15,
V3_16,
V3_17,
V3_18,
V3_19,
V3_20,
V3_21,
V3_22,
V3_23,
V3_24,
V3_25,
V3_26,
V3_27,
V3_28,
V3_29,
V3_30,
V3_31,
V3_32,
V3_33,
V3_34,
V3_35,
V3_36,
V3_37,
V3_38,
V3_39,
V3_40,
V3_41,
V3_42,
V3_43,
V3_44,
V3_45,
V3_46,
V3_47,
V3_48,
V3_49,
V3_50,
V3_51,
Latest,
}Expand description
SQLite compatibility target used to select grammar behavior.
Pin this when your application needs to parse according to a specific
SQLite release. Patch versions are intentionally ignored.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
V3_12
V3_13
V3_14
V3_15
V3_16
V3_17
V3_18
V3_19
V3_20
V3_21
V3_22
V3_23
V3_24
V3_25
V3_26
V3_27
V3_28
V3_29
V3_30
V3_31
V3_32
V3_33
V3_34
V3_35
V3_36
V3_37
V3_38
V3_39
V3_40
V3_41
V3_42
V3_43
V3_44
V3_45
V3_46
V3_47
V3_48
V3_49
V3_50
V3_51
Latest
No version constraint — use the latest grammar rules.
Implementations
Sourceimpl SqliteVersion
impl SqliteVersion
Sourcepub fn parse_with_latest(s: &str) -> Result<Self, String>
pub fn parse_with_latest(s: &str) -> Result<Self, String>
Parse a version string or the literal "latest".
The string "latest" (case-insensitive) maps to SqliteVersion::Latest.
All other inputs are forwarded to SqliteVersion::parse.
Errors
Returns Err if the version string is not recognised.